The REIDS_IsoformAssesment is an experimental function to analyze the isoform information based on the exon level values and the isoform composition.
REIDS_IsoformAssesment(geneIDs, IsoformInfo, ExonLevel, Groups, paired,
Location = NULL, Name = "REIDSIsoforms")A vector with the geneIDs to analyze.
The path to the Composition file created by REIDS_JunctionAssesment or CreateOutput.
The path to the ExonLevel.txt file
A list with elements speficifing the columns of the data in each group.
Logical. Are the groups paired samples?
A character string indication the place where the outputs are saved.
A character string with the name of the ouput file. Defaults to "REIDSIsoforms".
The function returns three files. The first file has name "Name_IsoformIndication.txt" and contains an assesment of the relative expression levels of the isoforms. A second file,"Name_ExonTesting.txt", shows information regarding the differential expression of exon. A final file,"Name_PossibelDEIsoforms" lists isoforms which might be differentially expressed between the groups.