Learn R Programming

REIDS (version 0.1.0)

TC12000010_ExonLevel: Exon level data

Description

An example data set containing the summarized expression values on the exon level of the probe sets of TC12000010.

Usage

data(TC12000010_ExonLevel)

Arguments

Format

An object of class "data.frame".

Examples

Run this code
# NOT RUN {
data(TC12000010_ExonLevel)
# }

Run the code above in your browser using DataLab