powered by
An example data set containing the summarized expression values on the exon level of the probe sets of TC12000010.
data(TC12000010_ExonLevel)
An object of class "data.frame".
"data.frame"
# NOT RUN { data(TC12000010_ExonLevel) # }
Run the code above in your browser using DataLab